@@ -51,7 +51,7 @@
  * proc index x { puts "I just played index $x" }
  *
  * synth "Hello world" synth -index 0 "This is some" -index 1
- * "really wierd" say -index 2 "text" say -reset
+ * "really weird" say -index 2 "text" say -reset
  *
  * The only difference bewtween say and synth is that synth
  * calls eciSynthesize and say doesn't.  You can put as many
@@ -74,7 +74,9 @@
 #define PACKAGENAME "tts"
 #define PACKAGEVERSION "1.0"
 #define ECILIBRARYNAME "libibmeci.so"
-
+// Returning to pre-pulse buffer size under pipewire
+// Get 2048 16 bit samples, 0.185760 seconds of audio per buffer
+#define ATCL_BUFFER_SIZE 1048576
 //>
 //< alsa: globals and defines
 
@@ -93,7 +95,7 @@ int waveBufferBytes = 0;
 //<decls and function prototypes
 
 /*
- * The following declarations are derived from the publically
+ * The following declarations are derived from the publicly
  * available documentation for ViaVoice TTS outloud. --they are
  * placed here to obviate the need for having the ViaVoice SDK
  * installed.
@@ -209,6 +211,13 @@ static size_t alsa_configure(void) {
   err = snd_pcm_hw_params_set_rate(AHandle, params, rate, 0);
   assert(err >= 0);
 
+  //>
+  //<buffer_size:
+
+  err = snd_pcm_hw_params_set_buffer_size(AHandle, params, ATCL_BUFFER_SIZE);
+  if (err < 0) {
+    fprintf(stderr, "Will use ALSA/Pulse defaults.\n");
+  }
   //>
   //<Access Mode:
   err = snd_pcm_hw_params_set_access(AHandle, params,
@@ -837,5 +846,6 @@ int SetLanguage(ClientData eciHandle, Tcl_Interp *interp, int objc,
 //<end of file
 // local variables:
 // folded-file: t
+// outline-regexp:  "^//<"
 // end:
 //>
